==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/core/src/test_framework/xmltest/XMLTestFormat.cpp <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "XMLTestFormat.h"

#define TEST_FACTORIES_AUTO_CLEANUP

#ifdef TEST_FACTORIES_AUTO_CLEANUP
    #include <core_api/AppContext.h>
    #include <test_framework/GTestFrameworkComponents.h>
#endif

//built-in test impls
#include <test_framework/xmltest/DocumentModelTests.h>
#include <test_framework/xmltest/DNASequenceObjectTests.h>
#include <test_framework/xmltest/AnnotationTableObjectTest.h>
#include <test_framework/xmltest/DNATranslationImplTests.h>
#include <test_framework/xmltest/XMLTestUtils.h>
#include <test_framework/xmltest/BioStruct3DObjectTests.h>
#include <test_framework/xmltest/TaskTests.h>
#include <util_tasks/SequenceWalkerTests/SequenceWalkerTests.h>

namespace GB2 {

XMLTestFactory::~XMLTestFactory() {
#ifdef TEST_FACTORIES_AUTO_CLEANUP
    GTestFormatRegistry* tfr = AppContext::getTestFramework()->getTestFormatRegistry();
    if (tfr!=NULL) {
        XMLTestFormat *xmlTestFormat = qobject_cast<XMLTestFormat*>(tfr->findFormat("XML"));
        if (xmlTestFormat!=NULL) {
            xmlTestFormat->unregisterTestFactory(this);
        }
    }
#endif
}



XMLTestFormat::XMLTestFormat() : GTestFormat("XML")
{
    registerBuiltInFactories();
}

XMLTestFormat::~XMLTestFormat() {
    foreach(XMLTestFactory* f, testFactories.values()) {
        delete f;
    }
}

GTest* XMLTestFormat::createTest(const QString& name, GTest* cp, const GTestEnvironment* env, const QByteArray& testData, QString& err) {
    QDomDocument doc;
    int line = 0;
    int col = 0;
    bool res = doc.setContent(testData, &err, &line, &col);
    if (!res) {
        err = tr("error_reading_test: ") + err;
        err+=tr(" line: %1 col: %2").arg(QString::number(line)).arg(QString::number(col));
        return NULL;
    }
    if (doc.doctype().name()!="UGENE_TEST_FRAMEWORK_TEST") {
        err = tr("not_a_test_file");
        return NULL;
    }
    QDomElement testEl = doc.documentElement();
    return createTest(name, cp, env, testEl, err);
}

GTest* XMLTestFormat::createTest(const QString& name, GTest* cp, const GTestEnvironment* env, const QDomElement& el, QString& err) {
    QString tagName = el.tagName();
    XMLTestFactory* f = testFactories.value(tagName);
    if (f == NULL) {
        err = tr("XMLTestFactory not found '%1'").arg(tagName);
        return NULL;
    }
    QList<GTest*> subs;
    GTest* t = f->createTest(this, name, cp, env, subs, el);
    return t;
}

bool XMLTestFormat::registerTestFactory(XMLTestFactory* tf) {
    const QString& tagName = tf->getTagName();
    if (testFactories.contains(tagName)) {
        return false;
    }
    testFactories[tagName] = tf;
    return true;
}

bool XMLTestFormat::unregisterTestFactory(XMLTestFactory* tf) {
    const QString& tagName = tf->getTagName();
    if (!testFactories.contains(tagName)) {
        return false;
    }
    testFactories.remove(tagName);
    return true;
}

void XMLTestFormat::registerBuiltInFactories() {
    { // multitest
        QList<XMLTestFactory*> fs = XMLTestUtils::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }

    { //Document model tests
        QList<XMLTestFactory*> fs = DocumentModelTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
   
   { //DNASequenceObject Tests
        QList<XMLTestFactory*> fs = DNASequenceObjectTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
    { //DNATranslationImplTests Tests
        QList<XMLTestFactory*> fs = DNATranslationImplTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
   	{ //Annotation Table Object Test
        QList<XMLTestFactory*> fs = AnnotationTableObjectTest::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
	{ //Sequence Walker Test
        QList<XMLTestFactory*> fs = SequenceWalkerTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }

	{ //BioStruct3D Object Tests
            QList<XMLTestFactory*> fs = BioStruct3DObjectTests::createTestFactories();
            foreach(XMLTestFactory* f, fs) {
                bool res = registerTestFactory(f);
                assert(res); Q_UNUSED(res);
            }
	}
    { //Task Tests
        QList<XMLTestFactory*> fs = TaskTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }


}



}//namespace

==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/core/src/test_framework/xmltest/XMLTestFormat.cpp <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#include "XMLTestFormat.h"

#define TEST_FACTORIES_AUTO_CLEANUP

#ifdef TEST_FACTORIES_AUTO_CLEANUP
    #include <core_api/AppContext.h>
    #include <test_framework/GTestFrameworkComponents.h>
#endif

//built-in test impls
#include <test_framework/xmltest/AddPartToSequenceTests.h>
#include <test_framework/xmltest/RemovePartFromSequenceTests.h>
#include <test_framework/xmltest/DocumentModelTests.h>
#include <test_framework/xmltest/DNASequenceObjectTests.h>
#include <test_framework/xmltest/AnnotationTableObjectTest.h>
#include <test_framework/xmltest/DNATranslationImplTests.h>
#include <test_framework/xmltest/XMLTestUtils.h>
#include <test_framework/xmltest/BioStruct3DObjectTests.h>
#include <test_framework/xmltest/TaskTests.h>
#include <test_framework/xmltest/FilesIndexingTests.h>
#include <test_framework/xmltest/AsnParserTests.h>
#include <test_framework/xmltest/SequenceWalkerTests.h>
#include <util_sec_struct_predict/SecStructPredictTests.h>


namespace GB2 {

XMLTestFactory::~XMLTestFactory() {
#ifdef TEST_FACTORIES_AUTO_CLEANUP
    GTestFormatRegistry* tfr = AppContext::getTestFramework()->getTestFormatRegistry();
    if (tfr!=NULL) {
        XMLTestFormat *xmlTestFormat = qobject_cast<XMLTestFormat*>(tfr->findFormat("XML"));
        if (xmlTestFormat!=NULL) {
            xmlTestFormat->unregisterTestFactory(this);
        }
    }
#endif
}



XMLTestFormat::XMLTestFormat() : GTestFormat("XML")
{
    registerBuiltInFactories();
}

XMLTestFormat::~XMLTestFormat() {
    foreach(XMLTestFactory* f, testFactories.values()) {
        delete f;
    }
}

GTest* XMLTestFormat::createTest(const QString& name, GTest* cp, const GTestEnvironment* env, const QByteArray& testData, QString& err) {
    QDomDocument doc;
    int line = 0;
    int col = 0;
    bool res = doc.setContent(testData, &err, &line, &col);
    if (!res) {
        err = QString("error_reading_test: ") + err;
        err+=QString(" line: %1 col: %2").arg(QString::number(line)).arg(QString::number(col));
        return NULL;
    }
    if (doc.doctype().name()!="UGENE_TEST_FRAMEWORK_TEST") {
        err = QString("not_a_test_file");
        return NULL;
    }
    QDomElement testEl = doc.documentElement();
    return createTest(name, cp, env, testEl, err);
}

GTest* XMLTestFormat::createTest(const QString& name, GTest* cp, const GTestEnvironment* env, const QDomElement& el, QString& err) {
    QString tagName = el.tagName();
    XMLTestFactory* f = testFactories.value(tagName);
    if (f == NULL) {
        err = QString("XMLTestFactory not found '%1'").arg(tagName);
        return NULL;
    }
    QList<GTest*> subs;
    GTest* t = f->createTest(this, name, cp, env, subs, el);
    return t;
}

bool XMLTestFormat::registerTestFactory(XMLTestFactory* tf) {
    const QString& tagName = tf->getTagName();
    if (testFactories.contains(tagName)) {
        return false;
    }
    testFactories[tagName] = tf;
    return true;
}

bool XMLTestFormat::unregisterTestFactory(XMLTestFactory* tf) {
    const QString& tagName = tf->getTagName();
    if (!testFactories.contains(tagName)) {
        return false;
    }
    testFactories.remove(tagName);
    return true;
}

void XMLTestFormat::registerBuiltInFactories() {
    { // multitest
        QList<XMLTestFactory*> fs = XMLTestUtils::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }

    { //Document model tests
        QList<XMLTestFactory*> fs = DocumentModelTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
   
   { //DNASequenceObject Tests
        QList<XMLTestFactory*> fs = DNASequenceObjectTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
    { //DNATranslationImplTests Tests
        QList<XMLTestFactory*> fs = DNATranslationImplTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
   	{ //Annotation Table Object Test
        QList<XMLTestFactory*> fs = AnnotationTableObjectTest::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
	{ //Sequence Walker Test
        QList<XMLTestFactory*> fs = SequenceWalkerTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }

	{ //BioStruct3D Object Tests
            QList<XMLTestFactory*> fs = BioStruct3DObjectTests::createTestFactories();
            foreach(XMLTestFactory* f, fs) {
                bool res = registerTestFactory(f);
                assert(res); Q_UNUSED(res);
            }
	}
    { //Task Tests
        QList<XMLTestFactory*> fs = TaskTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
    { // Indexing files tests
        QList<XMLTestFactory*> fs = FilesIndexingTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
    
    { // Add part to sequence tests
        QList<XMLTestFactory*> fs = AddPartToSequenceTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }
    
    { // Remove part to sequence tests
        QList<XMLTestFactory*> fs = RemovePartFromSequenceTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }

    { // AsnParser tests
        QList<XMLTestFactory*> fs = AsnParserTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }

    { // SecStructPredict tests
        QList<XMLTestFactory*> fs = SecStructPredictTests::createTestFactories();
        foreach(XMLTestFactory* f, fs) { 
            bool res = registerTestFactory(f);
            assert(res); Q_UNUSED(res);
        }
    }



    
}

}//namespace
